/****************************************************************************
* Title                 :   Stretch click
* Filename              :   Stretch.c
* Author                :   Lana Arsic
* Origin Date           :   27/06/2016
* Notes                 :   Stretch Example
*****************************************************************************/
/**************************CHANGE LIST **************************************
*
*    Date    Software Version    Initials       Description
*  27/06/16       6.6.3            LA        This is a demonstration of using Stretch click.
                                             Analog value on AN pin increases when stretching
*
*****************************************************************************/
/**
 * @file Stretch.c
 * @brief <h2> Stretch Example </h2>
 *
 * @par
 * Example for <a href="http://www.mikroe.com">MikroElektronika's</a>
 * Stretch click board.
*/

#include "Stretch.h"


// Lcd module connections
sbit LCD_RS at LATB4_bit;
sbit LCD_EN at LATB5_bit;
sbit LCD_D4 at LATB0_bit;
sbit LCD_D5 at LATB1_bit;
sbit LCD_D6 at LATB2_bit;
sbit LCD_D7 at LATB3_bit;

sbit LCD_RS_Direction at TRISB4_bit;
sbit LCD_EN_Direction at TRISB5_bit;
sbit LCD_D4_Direction at TRISB0_bit;
sbit LCD_D5_Direction at TRISB1_bit;
sbit LCD_D6_Direction at TRISB2_bit;
sbit LCD_D7_Direction at TRISB3_bit;
// End Lcd module connections

static unsigned int adc_rd;
static char txt[6];


static void readSensor();
static void set_adc();

/*
 * Read data from sensor
 * reads ADC value from AN pin
 */
static void readSensor()
{
    adc_rd = ADC_Get_Sample(2);                // Read RA2
    delay_ms(10);                              // Pause 10ms
}

/*
 * Set A/D register
 * set ADC on RA2
 */
static void set_adc()
{
    ANSELA = 0x04;                             // Set ADC on RA2
    TRISA = 0x04;                              // Set RA2 as input
    LATA = 0;
}

void main()
{
    set_adc();                                 // Set A/D register
    LCD_Init();                                // Initialize Lcd
    Lcd_Cmd(_LCD_CLEAR);                       // Clear display
    Lcd_Cmd(_LCD_CURSOR_OFF);                  // Cursor off
    Lcd_Out(1,1,"Stretch click");              // Write text in first row

    ADC_Init();                                // Initialize ADC
    delay_ms(100);                             // Pause of 100ms for ADC module stabilization

    while(1) {
        readSensor();                          // Read sensor
        WordToStr(adc_rd,&txt);                // Conversion int adc_rd to string txt
        LCD_Out(2,4,txt);                      // Print txt value on LCD
        delay_ms(500);                         // Pause 500ms
    }

}